View source: R/add_gitignore.R
| add_gitignore | R Documentation |
add_gitignore() fetch files using the API from
gitignore.io. Also,
add_gitignore() include tags (created by
ctags) into the gitignore file.
add_gitignore(type = "r")
type |
a character vector with the language to be ignored |
No return value, called for side effects (creates .gitignore, or
stops with an error if the file already exists).
add_gitignore() is inspired by
gitignore::gi_fetch_templates
and by some examples on the gitignore.io
wiki page.
if (interactive()) {
# Downloads from gitignore.io (requires network). Use combined `type` on
# first create, e.g. `add_gitignore(type = c("r", "python"))`.
add_gitignore()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.