R/deduplicate_by.R
deduplicate_by.RdThis function removes duplicate rows from a data frame while keeping the first occurrence of each unique combination of the specified grouping variables.
deduplicate_by(.data, ...)A data frame with duplicate rows removed, keeping only the first occurrence for each unique combination of grouping variables