na_count: Count NA frequency in data

View source: R/na_count.R

na_countR Documentation

Count NA frequency in data

Description

na_count() is a way to display the count and frequency of NA in data. It can be slow over large datasets.

Usage

na_count(data, sort = TRUE)

Arguments

data

a data frame

sort

If TRUE, sort rows by descending na_percent. If FALSE, keep column order from the input.

Value

a long-format tibble

Acknowledgment

I learned this way of exploring data though the excellent webinar taught by Emily Robinson.

Examples


na_data <- data.frame(c1 = c(1, NA), c2 = c(NA, NA))
na_data %>% na_count()


misc documentation built on April 8, 2026, 9:10 a.m.