| na_count | R Documentation |
na_count() is a way to display the count and frequency of NA in data. It
can be slow over large datasets.
na_count(data, sort = TRUE)
data |
a data frame |
sort |
If |
a long-format tibble
I learned this way of exploring data though the excellent webinar taught by Emily Robinson.
na_data <- data.frame(c1 = c(1, NA), c2 = c(NA, NA))
na_data %>% na_count()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.