quick_map: Create maps quickly

View source: R/quick_map.R

quick_mapR Documentation

Create maps quickly

Description

quick_map() allows the creation of maps quickly using {ggplot2}. For this reason, the resulting map is fully editable through {ggplot2} layers.

Usage

quick_map(region = NULL, type = NULL)

Arguments

region

character string or atomic vector containing countries names ou continents. Default is NULL.

type

character string informing map type. Can be "sf" or "ggplot"

Value

a ggplot object

Acknowledgment

quick_map() depends heavily on the data available by the {rnaturalearth} package. In this sense, quick_map() uses a wide and dirty filtering of this data to create the map.

Examples


if (interactive()) {
# plot a world map
quick_map()
# plot a new world map
quick_map(region = "Americas", type = "sf")
# using ggplot
quick_map(region = "Americas", type = "ggplot")
# edit using ggplot2 layers
quick_map() +
  ggplot2::theme_void() +
  ggplot2::geom_sf(fill = "white")
}


misc documentation built on April 8, 2026, 9:10 a.m.