| read_all_sheets_then_save_csv | R Documentation |
read_all_sheets_then_save_csv() just loops read_sheet_then_save_csv() over
the available excel sheets and save them in data/temp/extracted_sheets
read_all_sheets_then_save_csv(path_to_xlsx, dir_to_save = NULL)
path_to_xlsx |
a character vector with path to the excel file |
dir_to_save |
a character vector with the path to save the csv files. Default is NULL and save the csv files in the "data/temp/extracted_sheets" if it exists. |
A list (one element per sheet), each the return value of
read_sheet_then_save_csv() for that sheet (invisibly NULL per call).
See: read_sheet_then_save_csv
if (interactive()) {
# read and into a csv
misc::create_dirs("ma-box")
xlsx_file <- system.file("xlsx-examples", "mtcars_workbook_001.xlsx", package = "misc")
read_all_sheets_then_save_csv(
path_to_xlsx = xlsx_file,
dir_to_save = "ma-box"
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.