read_all_xlsx_then_save_csv: Read all sheets from all excel files and save into CSV files

read_all_xlsx_then_save_csvR Documentation

Read all sheets from all excel files and save into CSV files

Description

Following the same principle of read_all_sheets_then_save_csv read_all_xlsx_then_save_csv() just loop read_all_sheets_then_save_csv() over all available xlsx files

Usage

read_all_xlsx_then_save_csv(path_to_xlsx)

Arguments

path_to_xlsx

a character vector with the path to excel file

Value

A list (one element per .xlsx file found under path_to_xlsx), each the list returned by read_all_sheets_then_save_csv() for that workbook.

Acknowledgment

See: read_sheet_then_save_csv

Examples


if (interactive()) {
# read and into a csv
xlsx_dir <- system.file("xlsx-examples", package = "misc")
read_all_xlsx_then_save_csv(
  path_to_xlsx = xlsx_dir
)
}


misc documentation built on April 8, 2026, 9:10 a.m.