Opens data in VisiData through the Terminal application on macOS. If the input is an sf object, the geometry column will be dropped before viewing.
view_vd(data, type = "csv")Returns the input data invisibly
This function only works in interactive sessions on macOS. It creates a temporary file and opens it in VisiData through the Terminal application. The temporary filename includes a timestamp for identification.